import json
from app.models.base import redis_db_01


class UserDB:
    @staticmethod
    def get_user_info(user_name):
        """
            根据用户名获取结果
        :param order_id:
        :return:
        """
        key = f"user:{user_name}"
        user_info = redis_db_01.get(key)
        if user_info:
            return True
        return False



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# 说明：
#    MongoDBPro
# History:
# Date          Author    Version       Modification
# --------------------------------------------------------------------------------------------------
# 2024/4/17    xiatn     V00.01.000    新建
# --------------------------------------------------------------------------------------------------
from urllib import parse
from typing import List, Dict, Optional
from xtn_tools_pro.utils.time_utils import *
from pymongo import MongoClient as _MongoClient
from pymongo.database import Database as _Database
from pymongo.collection import Collection as _Collection
from pymongo.errors import DuplicateKeyError, BulkWriteError


class MongoDBPro:
    def __init__(self, ip=None, port=None, db=None, user_name=None, user_pass=None, url=None, **kwargs):
        if url:
            self.client = _MongoClient(url, **kwargs)
        else:
            self.client = _MongoClient(host=ip,
                                       port=port,
                                       username=user_name,
                                       password=user_pass,
                                       authSource=db)

        self.db = self.get_database(db)

    @classmethod
    def from_url(cls, url, **kwargs):
        url_parsed = parse.urlparse(url)
        # 获取 URL的协议
        db_type = url_parsed.scheme.strip()
        if db_type != "mongodb":
            raise Exception(
                "url error, expect mongodb://[username:password@]host1[:port1][,host2[:port2],...[,hostN[:portN]]][/[database][?options]], but get {}".format(
                    url
                ))
        return cls(url=url, **kwargs)

    def close(self):
        """
            关闭数据库
        :return:
        """
        self.client.close()

    def get_database(self, database, **kwargs) -> _Database:
        """
            根据db名获取数据库对象
        """
        return self.client.get_database(database, **kwargs)

    def get_collection(self, coll_name, **kwargs) -> _Collection:
        """
            根据集合名获取集合对象
        """
        return self.db.get_collection(coll_name, **kwargs)

    def run_command(self, command: Dict):
        """
            参考文档 https://www.geek-book.com/src/docs/mongodb/mongodb/docs.mongodb.com/manual/reference/command/index.html
        """
        return self.db.command(command)

    def find(self, coll_name: str, condition: Optional[Dict] = None,
             limit: int = 0, **kwargs) -> List[Dict]:
        """
            find
            coll_name:集合名称
            condition:查询条件 例如：{"name": "John"}、{"_id": "xxxxx"}
        """
        condition = {} if condition is None else condition
        command = {"find": coll_name, "filter": condition, "limit": limit}
        command.update(kwargs)
        result = self.run_command(command)
        cursor = result["cursor"]
        cursor_id = cursor["id"]
        while True:
            for document in cursor.get("nextBatch", cursor.get("firstBatch", [])):
                # 处理数据
                yield document
            if cursor_id == 0:
                # 游标已经完全遍历，没有剩余的结果可供获取
                # 游标的生命周期已经结束，例如在查询会话结束后。
                # 游标被显式地关闭，例如使用 db.killCursor() 命令关闭游标。
                break
            result = self.run_command(
                {
                    "getMore": cursor_id,  # 类似于mongo命令行中的it命令，通过索引id用于获取下一批结果
                    "collection": coll_name,
                    "batchSize": kwargs.get("batchSize", 100),
                }
            )
            # 覆盖原来的参数
            cursor = result["cursor"]
            cursor_id = cursor["id"]
            # print("下一批获取")

    def add_data_one(self, coll_name: str, data: Dict, insert_ignore=False,
                     is_add_create_time=False,
                     is_add_create_time_field_name="create_dt"):
        """
            添加单条数据
            coll_name: 集合名
            data: 单条数据
            insert_ignore: 索引冲突是否忽略 默认False
            is_add_create_time: 是否在数据中添加一个创建数据10时间戳字段 默认False不创建
            is_add_create_time_field_name: 自定义创建数据时间戳字段名：默认：create_dt
        Returns: 插入成功的行数
        """
        if is_add_create_time:
            data[is_add_create_time_field_name] = get_time_now_timestamp(is_time_10=True)
        collection = self.get_collection(coll_name)
        try:
            collection.insert_one(data)
        except DuplicateKeyError as e:
            if not insert_ignore:
                raise e
            return 0
        return 1

    def find_id_is_exist(self, coll_name, _id):
        """
            根据id查询id是否存在
        :param _id:id
        :return: 存在返回True 否则False
        """
        condition = {"_id": _id}
        status = list(self.find(coll_name, condition))
        if status:
            return True
        return False


if __name__ == '__main__':
    pass
    # mongo_db = MongoDBPro("127.0.0.1", 27017, "spider_pro")
    # # mongo_db.add_data_one("test", {"_id": "1", "data": "aaa"})
    # print(mongo_db.find_id_is_exist("test", "1"))
    # print(mongo_db.find_id_is_exist("test", "11"))



from flask_wtf.file import DataRequired
from app.validators.base import BaseForm as Form
from wtforms import StringField, FieldList, FormField



class xxxxxDictInfoForm(Form):
    xxxxx = StringField('xxxxx', validators=[DataRequired(message="order_id is required")])


class UpdateDataFileValidatorsForm(Form):
    result = FieldList(
        FormField(xxxxxDictInfoForm),  # 使用 FormField 包装子表单
        min_entries=1,
        validators=[DataRequired(message='xxx 不允许为空')]
    )



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from flask import request, json
from werkzeug.exceptions import HTTPException
from xtn_tools_pro.utils.time_utils import get_time_now_timestamp

class APIException(HTTPException):
    code = 500
    msg = 'sorry, we made a mistake'
    error_code = 5000
    data = {}
    data_type = "dict"

    def __init__(self, msg=None, code=None, error_code=None, headers=None, data=None, data_type=None):
        if code:
            self.code = code
        if error_code:
            self.error_code = error_code
        if msg:
            self.msg = msg
        if data:
            self.data = data
        if data_type == "list" and not data:
            self.data = []
        super(APIException, self).__init__(msg, None)

    def get_body(self, environ=None, scope=None):
        # 重写 父类的get_body
        body = dict(
            msg=self.msg,
            error_code=self.error_code,
            code=self.code,
            request=request.method + ' ' + self.get_url_no_param(),
            data=self.data,
            timestamp=get_time_now_timestamp(is_time_13=True)
        )
        text = json.dumps(body)
        return text

    def get_headers(self, environ=None, scope=None):
        """Get a list of headers."""
        return [('Content-Type', 'application/json')]

    @staticmethod
    def get_url_no_param():
        full_path = str(request.full_path)
        main_path = full_path.split('?')
        return main_path[0]



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# 说明：
#    文件
# History:
# Date          Author    Version       Modification
# --------------------------------------------------------------------------------------------------
# 2024/5/13    xiatn     V00.01.000    新建
# --------------------------------------------------------------------------------------------------
import os
import re


def get_file_extension(file_name):
    """
        根据文件名获取文件扩展名/后缀名
    :param file_name: 文件名称
    :return:
    """
    _, file_extension = os.path.splitext(file_name)
    return file_extension


def get_file_check_filename(file_name):
    """
        传入文件名返回一个合法的文件名 会替换掉一些特殊符号 常用于爬虫写文件时文件名中带有特殊符号的情况...
    :param filename: 文件名
    :return:
    """
    file_extension = get_file_extension(file_name)
    # 删除非法字符
    sanitized_filename = re.sub(r'[\/:*?"<>|]', '', file_name)
    max_length = 255  # 操作系统限制文件名的最大长度为255个
    sanitized_filename = sanitized_filename[:max_length]
    return sanitized_filename


def mkdirs_dir(file_path):
    """
        传入一个文件路径创建对应的文件夹，如果某一段不存在则一路创建下去
    :param file_path:
    :return:
    """
    directory = os.path.dirname(file_path)
    if not os.path.exists(directory):
        os.makedirs(directory)


def check_file_exists(file_path):
    """
        传入一个文件路径，判断文件是否存在
    :param file_path:
    :return:
    """
    if os.path.exists(file_path):
        return True
    return False


def is_dir(dir_path):
    """
        传入文件夹判断是否为文件夹或文件夹是否存在
        传入的如果是文件路径则返回False
        传入的如果是一个不存在的文件夹则返回False
    :param dir_path:
    :return:
    """
    if not os.path.isdir(dir_path):
        return False
    return True


def get_listdir(dir_path):
    """
        获取指定文件夹下的所有文件
    :param dir_path:
    :return:
    """
    return os.listdir(dir_path)


if __name__ == '__main__':
    pass
    print(get_file_extension('file/2024-04-19/BOSCH GEX 125-1A/125-1AE砂磨机操作说明书:[1]_jingyan.txt'))
    print(get_file_check_filename('file/2024-04-19/BOSCH GEX 125-1A/125-1AE砂磨机操作说明书:[1]_jingyan.txt'))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import jwt
from flask import current_app, g
from app.models.base import logger
from app.models.user import UserDB
from flask_httpauth import HTTPBasicAuth
from app.libs.error_code import TokenException

user_auth = HTTPBasicAuth()


@user_auth.verify_password
def user_verify_password(token, password):
    user_info = verify_user_auth_token(token)
    # print(user_info)
    if not user_info:
        # token验证不通过
        raise TokenException()
    # token验证通过
    g.user = user_info
    return True


def verify_user_auth_token(token):
    secret_key = current_app.config['SECRET_KEY']
    try:
        payload = jwt.decode(token, secret_key, algorithms=["HS256"])
        # print("payload",payload)
        if not payload:
            logger.critical(f"验证身份失败")
            return
        logger.debug(f"验证身份成功,{payload},{token}")
        return payload
    except Exception as e:
        logger.critical(f"验证身份失败,{e}")
    return



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json
import random
from wtforms import Form
from flask import request
from app.libs.error_code import ValidatorsErrorException


class BaseForm(Form):
    def __init__(self, formdata=None, obj=None, prefix='', data=None, meta=None, **kwargs):
        # 合并请求中的数据
        request_data = request.get_json(silent=True) or {}
        values = request.values.to_dict()
        args = request.args.to_dict()
        file_args = request.files.to_dict()

        combined_data = {}
        combined_data.update(self.validate_data_type(request_data))
        combined_data.update(self.validate_data_type(values))
        combined_data.update(self.validate_data_type(args))
        combined_data.update(self.validate_data_type(file_args))

        # 合并传入的 data 参数（如果有）
        if data is not None:
            combined_data.update(data)

        # 调用父类构造函数，传递所有参数
        super(BaseForm, self).__init__(
            formdata=formdata,
            obj=obj,
            prefix=prefix,
            data=combined_data,
            meta=meta,
            **kwargs
        )

    def validate_for_api(self):
        valid = super(BaseForm, self).validate()
        if not valid:
            # 只返回一个错误
            error_msg = ""
            for error_k, error_v in self.errors.items():
                # print(error_k, error_v)
                if not error_v: continue
                error_v_item = error_v[0]
                if not error_v_item: continue
                if type(error_v_item) == str:
                    error_msg = error_v_item
                    break
                if type(error_v_item) == dict:
                    first_key = next(iter(error_v_item))
                    first_value = error_v_item[first_key]
                    if not first_value: continue
                    error_msg = first_value[0]
                    break

            raise ValidatorsErrorException(msg=error_msg)

        return self

    def validate_data_type(self, data):
        if type(data) == str:
            data = json.loads(data)
        return data



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# 说明：
#    加解密、编解码
# History:
# Date          Author    Version       Modification
# --------------------------------------------------------------------------------------------------
# 2024/5/13    xiatn     V00.01.000    新建
# --------------------------------------------------------------------------------------------------
import jwt
import pyotp
import base64
import hashlib
import secrets


def get_md5_32(s: str, is_upper=False):
    """
        获取文本的md5值 32位
    :param s: 文本
    :param is_upper: 是否转大写 默认False
    :return:
    """
    # s.encode()#变成bytes类型才能加密
    m = hashlib.md5(s.encode())  # 长度是32
    if is_upper:
        return m.hexdigest().upper()
    return m.hexdigest()


def get_md5_16(s: str, is_upper=False):
    """
        获取文本的md5值 16位
    :param s: 文本
    :param is_upper: 是否转大写 默认False
    :return:
    """
    result = get_md5_32(s, is_upper)
    return result[8:24]


def get_binary_content_md5_32(content, is_upper=False):
    """
        二进制内容md5 例如图片
    :param content: 二进制内容
    :param is_upper: 是否转大写 默认False
    :return:
    """
    md5_hash = hashlib.md5(content)
    md5_hexdigest = md5_hash.hexdigest()
    if is_upper:
        return md5_hexdigest.upper()
    return md5_hexdigest


def get_binary_content_md5_16(content, is_upper=False):
    """
        二进制内容md5 例如图片
    :param content: 二进制内容
    :param is_upper: 是否转大写 默认False
    :return:
    """
    result = get_binary_content_md5_32(content, is_upper)
    return result[8:24]


def get_file_md5_32(file_path, is_upper=False):
    """
        获取文件md5值
    :param file_path: 文件路径
    :param is_upper: 是否转大写 默认False
    :return:
    """
    with open(file_path, 'rb') as file:
        data = file.read()
        md5_hash = hashlib.md5(data).hexdigest()
    if is_upper:
        return md5_hash.upper()
    return md5_hash


def get_file_md5_16(file_path, is_upper=False):
    """
        获取文件md5值
    :param file_path: 文件路径
    :param is_upper: 是否转大写 默认False
    :return:
    """
    result = get_file_md5_32(file_path, is_upper)
    return result[8:24]


def get_sha1(s: str, is_upper=False):
    """
        sha1
    :param s: 文本
    :param is_upper: 是否转大写 默认False
    :return:
    """
    # 使用sha1算法进行哈希
    sha1_hash = hashlib.sha1(s.encode()).hexdigest()
    if is_upper:
        return sha1_hash.upper()
    return sha1_hash


def get_base64_encode(s: str):
    """
        base64 编码
    :param s: 文本
    :return:
    """
    # 将字符串编码为 bytes
    data_bytes = s.encode('utf-8')
    # 使用 base64 进行编码
    encoded_bytes = base64.b64encode(data_bytes)
    # 将编码后的 bytes 转换为字符串
    encoded_string = encoded_bytes.decode('utf-8')
    return encoded_string


def generate_bearer_token(secret_key, expiration=0, algorithm='HS256', **kwargs):
    """
    生成 Bearer Token
    :param secret_key: 用于加密的密钥
    :param expiration: 过期时间戳,0则表示不过期
    :param algorithm: 使用的加密算法（默认是 HS256）HS256、HS384、HS512
    :param kwargs: 其他自定义的 Token 数据
    :return: 生成的 Bearer Token
    """
    payload = {
        **kwargs  # 将其他参数添加到 payload
    }
    if expiration:
        payload['exp'] = expiration

    token = jwt.encode(payload, secret_key, algorithm=algorithm)
    return token


def generate_secret_key(length=32):
    """
    生成一个随机的 secret key
    :param length: key 的长度，默认为 32
    :return: 生成的 secret key
    """
    return secrets.token_hex(length)


def img_bytes_to_str(img_data: bytes):
    """
        图片数据 bytes_to_str
    :param img_data:
    :return:
    """
    return img_data.decode('latin1')


def img_str_to_bytes(img_data: str):
    """
        图片数据 str_to_bytes
    :param img_data:
    :return:
    """
    return img_data.encode('latin1')


def get_2FA(secret):
    """
        计算 2FA
    :param secret:
    :return:
    """
    totp = pyotp.TOTP(secret)
    return str(totp.now())


if __name__ == '__main__':
    print(get_2FA('ninqzrh367u3iahpi2mum36bgfvouv5m'))
